@@ -18,7 +18,8 @@
     opts[["collection"]] = match.arg(opts[["collection"]], 
                                      c("CORE", "CNE", "PHYLOFACTS", 
                                        "SPLICE", "POLII", "FAM", 
-                                       "PBM", "PBM_HOMEO", "PBM_HLH"))
+                                       "PBM", "PBM_HOMEO", "PBM_HLH",
+                                       "UNVALIDATED"))
 
   if(!"all_versions" %in% names(opts))
     opts[["all_versions"]] = FALSE
@@ -343,6 +344,17 @@ setMethod("getMatrixByID", "JASPAR2018",
             getMatrixByID(x@db, ID)
           }
 )
+setMethod("getMatrixByID", "JASPAR2020",
+          function(x, ID){
+            getMatrixByID(x@db, ID)
+          }
+)
+
+setMethod("getMatrixByID", "JASPAR2022",
+          function(x, ID){
+            getMatrixByID(x@db, ID)
+          }
+)
 
 ### get_Matrix_by_name fetches matrix data under 
 ### the given name from the database and returns a XMatrix object.
@@ -412,6 +424,18 @@ setMethod("getMatrixByName", "JASPAR2018",
           }
 )
 
+setMethod("getMatrixByName", "JASPAR2020",
+          function(x, name){
+            getMatrixByName(x@db, name)
+          }
+)
+
+setMethod("getMatrixByName", "JASPAR2022",
+          function(x, name){
+            getMatrixByName(x@db, name)
+          }
+)
+
 ### get_MatrixSet fetches matrix data under for all matrices in the database matching criteria defined by the named arguments and returns a XMatrixList object
 # Returns : a XMatrixList object
 # Notes: This method accepts named arguments, corresponding to arbitrary tags, and also some utility functions. Note that this is different from JASPAR2 and to some extent JASPAR4. As any tag is supported for database storage, any tag can be used for information retrieval. Additionally, arguments as 'name','class','collection' can be used (even though they are not tags). By default, only the last version of the matrix is given. The only way to get older matrices out of this to use an array of IDs with actual versions like MA0001.1, or set the argyment -all_versions=>1, in which  case you get all versions for each stable ID.
@@ -502,6 +526,18 @@ setMethod("getMatrixSet", "JASPAR2018",
           }
 )
 
+setMethod("getMatrixSet", "JASPAR2020",
+          function(x, opts){
+            getMatrixSet(x@db, opts)
+          }
+)
+           
+setMethod("getMatrixSet", "JASPAR2022",
+          function(x, opts){
+            getMatrixSet(x@db, opts)
+          }
+)
+
 setMethod("deleteMatrixHavingID", "SQLiteConnection",
 # Deletes the matrix having the given ID from the database
 # Args    : (ID)
@@ -553,6 +589,17 @@ setMethod("deleteMatrixHavingID", "JASPAR2018",
           }
 )
 
+setMethod("deleteMatrixHavingID", "JASPAR2020",
+          function(x, IDs){
+            deleteMatrixHavingID(x@db, IDs)
+          }
+)
+
+setMethod("deleteMatrixHavingID", "JASPAR2022",
+          function(x, IDs){
+            deleteMatrixHavingID(x@db, IDs)
+          }
+)
 
 ### ------------------------------------------------------------
 ### utilities functions for store_Matrix
@@ -717,6 +764,19 @@ setMethod("storeMatrix", signature(x="JASPAR2018", pfmList="PFMatrix"),
             storeMatrix(x@db, pfmList)
           }
 )
+
+setMethod("storeMatrix", signature(x="JASPAR2020", pfmList="PFMatrix"),
+          function(x, pfmList){
+            storeMatrix(x@db, pfmList)
+          }
+)
+           
+setMethod("storeMatrix", signature(x="JASPAR2022", pfmList="PFMatrix"),
+          function(x, pfmList){
+            storeMatrix(x@db, pfmList)
+          }
+)
+           
 setMethod("storeMatrix", signature(x="JASPAR2014", 
                                    pfmList="PFMatrixList"),
           function(x, pfmList){
@@ -736,6 +796,20 @@ setMethod("storeMatrix", signature(x="JASPAR2018",
           }
 )
 
+setMethod("storeMatrix", signature(x="JASPAR2020",
+                                   pfmList="PFMatrixList"),
+          function(x, pfmList){
+            storeMatrix(x@db, pfmList)
+          }
+)
+        
+setMethod("storeMatrix", signature(x="JASPAR2022",
+                                   pfmList="PFMatrixList"),
+          function(x, pfmList){
+            storeMatrix(x@db, pfmList)
+          }
+)           
+
 ### -----------------------------------------------------------------
 ### initialize the jaspar 2014, 2016 stype db. create empty tables.
 ###
@@ -798,7 +872,7 @@ setMethod("storeMatrix", signature(x="JASPAR2018",
 ### Until now, the table definitions for JASPAR2014, JASPAR2016 and 
 ###   JASPARE2018 are same.
 setMethod("initializeJASPARDB", "SQLiteConnection",
-          function(x, version=c("2014", "2016", "2018")){
+          function(x, version=c("2014", "2016", "2018", "2020", "2022")){
             version <- match.arg(version)
             .create_tables(x)
             return("Success")
@@ -806,7 +880,7 @@ setMethod("initializeJASPARDB", "SQLiteConnection",
           )
 
 setMethod("initializeJASPARDB", "character",
-          function(x, version=c("2014", "2016", "2018")){
+          function(x, version=c("2014", "2016", "2018", "2020", "2022")){
             con = dbConnect(SQLite(), x)
             on.exit(dbDisconnect(con))
             initializeJASPARDB(con, version=version)
@@ -814,19 +888,30 @@ setMethod("initializeJASPARDB", "character",
           )
 
 setMethod("initializeJASPARDB", "JASPAR2014",
-          function(x, version=c("2014", "2016", "2018")){
+          function(x, version=c("2014", "2016", "2018", "2020", "2022")){
             initializeJASPARDB(x@db, version="2014")
           }
           )
 
 setMethod("initializeJASPARDB", "JASPAR2016",
-          function(x, version=c("2014", "2016", "2018")){
+          function(x, version=c("2014", "2016", "2018", "2020", "2022")){
             initializeJASPARDB(x@db, version="2016")
           }
           )
 setMethod("initializeJASPARDB", "JASPAR2018",
-          function(x, version=c("2014", "2016", "2018")){
+          function(x, version=c("2014", "2016", "2018", "2020", "2022")){
             initializeJASPARDB(x@db, version="2018")
           }
 )
+setMethod("initializeJASPARDB", "JASPAR2020",
+          function(x, version=c("2014", "2016", "2018", "2020", "2022")){
+            initializeJASPARDB(x@db, version="2020")
+          }
+)
+           
+setMethod("initializeJASPARDB", "JASPAR2022",
+          function(x, version=c("2014", "2016", "2018", "2020", "2022")){
+            initializeJASPARDB(x@db, version="2022")
+          }
+)
 
